summaryrefslogtreecommitdiffstats
path: root/cpukit/rtems/include/rtems/rtems/tasks.h
diff options
context:
space:
mode:
Diffstat (limited to 'cpukit/rtems/include/rtems/rtems/tasks.h')
-rw-r--r--cpukit/rtems/include/rtems/rtems/tasks.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/cpukit/rtems/include/rtems/rtems/tasks.h b/cpukit/rtems/include/rtems/rtems/tasks.h
index 2bd7236a80..d11e0bc522 100644
--- a/cpukit/rtems/include/rtems/rtems/tasks.h
+++ b/cpukit/rtems/include/rtems/rtems/tasks.h
@@ -38,7 +38,7 @@
#include <rtems/score/states.h>
#include <rtems/score/thread.h>
#include <rtems/rtems/types.h>
-#include <rtems/rtems/eventset.h>
+#include <rtems/rtems/event.h>
#include <rtems/rtems/asr.h>
#include <rtems/rtems/attr.h>
#include <rtems/rtems/status.h>
@@ -210,8 +210,8 @@ typedef struct {
* notespads are disabled by the application configuration.
*/
typedef struct {
- /** This field contains the pending events for this task. */
- rtems_event_set pending_events;
+ /** This field contains the event control for this task. */
+ Event_Control Event;
/** This field contains the Classic API Signal information for this task. */
ASR_Information Signal;
/**